<?php

namespace Drupal\ckmoon\Plugin\CKEditorPlugin;

use Drupal\ckeditor\CKEditorPluginBase;
use Drupal\ckeditor\CKEditorPluginConfigurableInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\editor\Entity\Editor;

/**
 * Defines the "ckmoon" plugin.
 *
 * @CKEditorPlugin(
 *   id = "ckmoon",
 *   label = @Translation("CK Moon"),
 *   module = "ckmoon"
 * )
 */
class CkMoon extends CKEditorPluginBase implements CKEditorPluginConfigurableInterface {

  /**
   * Implements \Drupal\ckeditor\Plugin\CKEditorPluginInterface::isInternal().
   */
  public function isInternal() {
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function getFile() {
    return drupal_get_path('module', 'ckmoon') . '/js/plugins/ckmoon/plugin.js';
  }

  /**
   * {@inheritdoc}
   */
  public function getLibraries(Editor $editor) {
    return [
      'core/drupal.ajax',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getConfig(Editor $editor) {
    $settings = $editor->getSettings();
    $config = [];

    if (!empty($settings['plugins']['ckmoon']['ckmoon']['prefix'])) {
      $config['ckmoon_prefix'] = $settings['plugins']['ckmoon']['ckmoon']['prefix'];
    }

    return $config;
  }

  /**
   * {@inheritdoc}
   */
  public function getButtons() {
    return [
      'CkMoon' => [
        'label' => $this->t('Ckmoon'),
        'image' => drupal_get_path('module', 'ckmoon') . '/js/plugins/ckmoon/icons/ckmoon.png',
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state, Editor $editor) {

    $settings = $editor->getSettings();

    $config = [
      'json' => '',
      'prefix' => '',
    ];

    if (isset($settings['plugins']['ckmoon']['ckmoon'])) {
      $config = $settings['plugins']['ckmoon']['ckmoon'];
    }

    $form['ckmoon'] = [
      '#type' => 'container',
    ];

    $form['ckmoon']['json'] = [
      '#type' => 'textfield',
      '#title' => 'selection.json',
      '#description' => $this->t('Path to selection.json relative to the current default theme directory'),
      '#default_value' => $config['json'],
    ];

    $form['ckmoon']['prefix'] = [
      '#type' => 'textfield',
      '#title' => 'Icon class prefix',
      '#description' => $this->t('If your icon classes are prefixed, please enter it here'),
      '#default_value' => $config['prefix'],
    ];

    return $form;
  }

}
